==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DpsJednostkaDane.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypDanychOJednostce;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DpsJednostkaDane extends GenericDPSObject {
    /**
     * DPS_JEDNOSTKA_DANE.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DPS_JEDNOSTKA_DANE.DPS_JEDNOSTKA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dpsJednostkaId;

    /**
     * DPS_JEDNOSTKA_DANE.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypDanychOJednostce typ;

    /**
     * DPS_JEDNOSTKA_DANE.WARTOSC_I
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer wartoscI;

    /**
     * DPS_JEDNOSTKA_DANE.WARTOSC_S
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String wartoscS;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DPS_JEDNOSTKA_DANE.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DPS_JEDNOSTKA_DANE.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DPS_JEDNOSTKA_DANE.DPS_JEDNOSTKA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDpsJednostkaId() {
        return dpsJednostkaId;
    }

    /**
     * DPS_JEDNOSTKA_DANE.DPS_JEDNOSTKA_ID
     *
     * @param dpsJednostkaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDpsJednostkaId(Long dpsJednostkaId) {
        this.dpsJednostkaId = dpsJednostkaId;
    }

    /**
     * @return DPS_JEDNOSTKA_DANE.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypDanychOJednostce getTyp() {
        return typ;
    }

    /**
     * DPS_JEDNOSTKA_DANE.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypDanychOJednostce typ) {
        this.typ = typ;
    }

    /**
     * @return DPS_JEDNOSTKA_DANE.WARTOSC_I
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getWartoscI() {
        return wartoscI;
    }

    /**
     * DPS_JEDNOSTKA_DANE.WARTOSC_I
     *
     * @param wartoscI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartoscI(Integer wartoscI) {
        this.wartoscI = wartoscI;
    }

    /**
     * @return DPS_JEDNOSTKA_DANE.WARTOSC_S
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getWartoscS() {
        return wartoscS;
    }

    /**
     * DPS_JEDNOSTKA_DANE.WARTOSC_S
     *
     * @param wartoscS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartoscS(String wartoscS) {
        this.wartoscS = wartoscS == null ? null : wartoscS.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DpsJednostkaDane other = (DpsJednostkaDane) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDpsJednostkaId() == null ? other.getDpsJednostkaId() == null : this.getDpsJednostkaId().equals(other.getDpsJednostkaId()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getWartoscI() == null ? other.getWartoscI() == null : this.getWartoscI().equals(other.getWartoscI()))
            && (this.getWartoscS() == null ? other.getWartoscS() == null : this.getWartoscS().equals(other.getWartoscS()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDpsJednostkaId() == null) ? 0 : getDpsJednostkaId().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getWartoscI() == null) ? 0 : getWartoscI().hashCode());
        result = prime * result + ((getWartoscS() == null) ? 0 : getWartoscS().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dpsJednostkaId=").append(dpsJednostkaId);
        sb.append(", typ=").append(typ);
        sb.append(", wartoscI=").append(wartoscI);
        sb.append(", wartoscS=").append(wartoscS);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DpsJednostkaDane.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypDanychOJednostce;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DpsJednostkaDane extends GenericDPSObject {
    /**
     * DPS_JEDNOSTKA_DANE.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DPS_JEDNOSTKA_DANE.DPS_JEDNOSTKA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dpsJednostkaId;

    /**
     * DPS_JEDNOSTKA_DANE.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypDanychOJednostce typ;

    /**
     * DPS_JEDNOSTKA_DANE.WARTOSC_I
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer wartoscI;

    /**
     * DPS_JEDNOSTKA_DANE.WARTOSC_S
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String wartoscS;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DPS_JEDNOSTKA_DANE.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DPS_JEDNOSTKA_DANE.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DPS_JEDNOSTKA_DANE.DPS_JEDNOSTKA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDpsJednostkaId() {
        return dpsJednostkaId;
    }

    /**
     * DPS_JEDNOSTKA_DANE.DPS_JEDNOSTKA_ID
     *
     * @param dpsJednostkaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDpsJednostkaId(Long dpsJednostkaId) {
        this.dpsJednostkaId = dpsJednostkaId;
    }

    /**
     * @return DPS_JEDNOSTKA_DANE.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypDanychOJednostce getTyp() {
        return typ;
    }

    /**
     * DPS_JEDNOSTKA_DANE.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypDanychOJednostce typ) {
        this.typ = typ;
    }

    /**
     * @return DPS_JEDNOSTKA_DANE.WARTOSC_I
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getWartoscI() {
        return wartoscI;
    }

    /**
     * DPS_JEDNOSTKA_DANE.WARTOSC_I
     *
     * @param wartoscI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartoscI(Integer wartoscI) {
        this.wartoscI = wartoscI;
    }

    /**
     * @return DPS_JEDNOSTKA_DANE.WARTOSC_S
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getWartoscS() {
        return wartoscS;
    }

    /**
     * DPS_JEDNOSTKA_DANE.WARTOSC_S
     *
     * @param wartoscS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartoscS(String wartoscS) {
        this.wartoscS = wartoscS == null ? null : wartoscS.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DpsJednostkaDane other = (DpsJednostkaDane) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDpsJednostkaId() == null ? other.getDpsJednostkaId() == null : this.getDpsJednostkaId().equals(other.getDpsJednostkaId()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getWartoscI() == null ? other.getWartoscI() == null : this.getWartoscI().equals(other.getWartoscI()))
            && (this.getWartoscS() == null ? other.getWartoscS() == null : this.getWartoscS().equals(other.getWartoscS()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDpsJednostkaId() == null) ? 0 : getDpsJednostkaId().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getWartoscI() == null) ? 0 : getWartoscI().hashCode());
        result = prime * result + ((getWartoscS() == null) ? 0 : getWartoscS().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dpsJednostkaId=").append(dpsJednostkaId);
        sb.append(", typ=").append(typ);
        sb.append(", wartoscI=").append(wartoscI);
        sb.append(", wartoscS=").append(wartoscS);
        sb.append("]");
        return sb.toString();
    }
}
